@@ -2,6 +2,7 @@
 package glesys
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"net/http"
@@ -10,6 +11,7 @@ import (
 
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/glesys/internal"
 )
 
 const (
@@ -55,7 +57,9 @@ func NewDefaultConfig() *Config {
 
 // DNSProvider implements the challenge.Provider interface.
 type DNSProvider struct {
-	config        *Config
+	config *Config
+	client *internal.Client
+
 	activeRecords map[string]int
 	inProgressMu  sync.Mutex
 }
@@ -90,8 +94,15 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 		return nil, fmt.Errorf("glesys: invalid TTL, TTL (%d) must be greater than %d", config.TTL, minTTL)
 	}
 
+	client := internal.NewClient(config.APIUser, config.APIKey)
+
+	if config.HTTPClient != nil {
+		client.HTTPClient = config.HTTPClient
+	}
+
 	return &DNSProvider{
 		config:        config,
+		client:        client,
 		activeRecords: make(map[string]int),
 	}, nil
 }
@@ -103,7 +114,7 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 	// find authZone
 	authZone, err := dns01.FindZoneByFqdn(info.EffectiveFQDN)
 	if err != nil {
-		return fmt.Errorf("glesys: findZoneByFqdn failure: %w", err)
+		return fmt.Errorf("glesys: could not find zone for domain %q (%s): %w", domain, info.EffectiveFQDN, err)
 	}
 
 	subDomain, err := dns01.ExtractSubDomain(info.EffectiveFQDN, authZone)
@@ -111,14 +122,12 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 		return fmt.Errorf("glesys: %w", err)
 	}
 
-	// acquire lock and check there is not a challenge already in
-	// progress for this value of authZone
+	// acquire lock and check there is not a challenge already in progress for this value of authZone
 	d.inProgressMu.Lock()
 	defer d.inProgressMu.Unlock()
 
 	// add TXT record into authZone
-	// TODO(ldez) replace domain by FQDN to follow CNAME.
-	recordID, err := d.addTXTRecord(domain, dns01.UnFqdn(authZone), subDomain, info.Value, d.config.TTL)
+	recordID, err := d.client.AddTXTRecord(context.Background(), dns01.UnFqdn(authZone), subDomain, info.Value, d.config.TTL)
 	if err != nil {
 		return err
 	}
@@ -144,8 +153,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 	delete(d.activeRecords, info.EffectiveFQDN)
 
 	// delete TXT record from authZone
-	// TODO(ldez) replace domain by FQDN to follow CNAME.
-	return d.deleteTXTRecord(domain, recordID)
+	return d.client.DeleteTXTRecord(context.Background(), recordID)
 }
 
 // Timeout returns the values (20*time.Minute, 20*time.Second) which
